AssetString class
Represents a string-base asset
Constructors
- AssetString.from(String content, String targetPath)
-
Creates a new AssetString with the provided
content.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetPath → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the underlying content of the asset as a String.
override
-
writeTo(
{File? file, String? chmod, bool noClobber = false}) → bool -
Write the asset content to the specified
file, or the targetPath if null, optionally setting permissions specified inchmod. If the file exists andnoClobberistrue, specified permissions will still be set but the file won't be overwritten.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited